# *refellips*

![Github Action](https://github.com/refnx/refellips/workflows/Test/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/refellips/badge/?version=latest)](https://refellips.readthedocs.io/en/latest/?badge=latest)

Spectroscopic ellipsometry data analysis in Python. Documentation at https://refellips.readthedocs.io.